@@ -12,13 +12,9 @@ class MachineOperationMode(Enum):
 
 
 class ZoneMode(Enum):
-    STOP = 0
-    COLD = 1
-    HOT_AIR = 2
-    AIR = 3
-    FLOOR_HOT = 4
-    HOTPLUS = 5
-
+    COMFORT = 0
+    ECO = 1
+    STANDBY = 2
 
 class FancoilSpeed(Enum):
     AUTOMATIC = 0
